#
# spec file for mame
#
# Copyright (c) 2011 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

Name:           mame
Version:        0.144
Release:        1.1
Summary:        Versatile Arcade Machine Emulator
Group:          System/Emulators/Other
License:        MAME License and BSD3c
Url:            http://mamedev.org/
BuildRequires:  gcc-c++
BuildRequires:  Mesa-devel
BuildRequires:  gtk2-devel
BuildRequires:  gconf2-devel
BuildRequires:  libSDL-devel
BuildRequires:  libSDL_ttf-devel
BuildRequires:  libexpat-devel
BuildRequires:  zlib-devel
# Source obtained from http://mamedev.org/release.html
# Repackaged, because the upstream sources are a zip that contains another zip:
Source:         mame-%{version}.tar.bz2
Source11:       mame.ini.in
Patch0:         mame-fix-buildsystem.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
MAME is an arcade machine emulator covering a broad spectrum of hardware
ranging from the very earliest CPU-based systems to much more modern 3D
platforms.  In conjuntion with ROM and CHD images "dumped" from arcade games'
original circuit-board ROM chips, hard disks, and CD-ROMs which are not
included in this package it allows you to play thousands of arcade video games.

%package tools
Summary:        Tools for mame
Requires:       %{name} = %{version}-%{release}
Group:          System/Emulators/Other

%description tools
This package contains tools for mame.


%prep
%setup -q
# convert lineendings
find . -type f -and -not -name '*.png' | xargs sed -i -e 's/\r$//'

%patch0 -p1

sed -e "s,@DATADIR@,%{_datadir},g"\
       -e "s,@SYSCONFDIR@,%{_sysconfdir},g" %SOURCE11 >mame.ini

# use date of last changelog entry instead of __DATE__ macro
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
sed -i "s/__DATE__/${DATE}/g" src/version.c

%build
make %{?_smp_mflags} \
    NOWERROR=1 \
    OPTIMIZE=2 \
    BUILD_EXPAT=1 \
    BUILD_ZLIB=1 \
    AR="%{__ar}" \
    CC="%{__cc}" \
    LD="%{__cxx}" \
    RM="%{__rm} -f" \
    SYMBOLS=1 \
    SYMLEVEL=2 \
    FULLNAME="mame" \
    OPT_FLAGS="%{optflags} -fno-strict-aliasing -DINI_PATH='\"%{_sysconfdir}/mame;\"'" all

%install
for mame_data_dir in artwork chds cheats crosshair ctrlr effects fonts keymaps \
        roms samples; do
    install -d -m 755 %{buildroot}%{_datadir}/mame/$mame_data_dir
done
install -d -m 755 %{buildroot}%{_sysconfdir}/mame
install -m 644 mame.ini %{buildroot}%{_sysconfdir}/mame/mame.ini
install -d -m 755 %{buildroot}%{_bindir}
install -m 755 mame %{buildroot}%{_bindir}/mame
install -d -m 755 %{buildroot}%{_bindir}
install -m 755 chdman jedutil ldresample ldverify romcmp unidasm \
        %{buildroot}%{_bindir}
for mame_tool in regrep srcclean src2html split testkeys; do
    install -m 755 $mame_tool %{buildroot}%{_bindir}/mame-$mame_tool
done
install -d -m 755 %{buildroot}%{_mandir}/man6
install -d -m 755 %{buildroot}%{_mandir}/man1
pushd src/osd/sdl/man/
sed 's/MAME 1/MAME 6/g' mame.1 >mame.6
sed 's/testkeys/mame-testkeys/g' testkeys.1 >mame-testkeys.1
install -m 644 chdman.1 jedutil.1 ldverify.1 mame-testkeys.1 romcmp.1 \
        %{buildroot}%{_mandir}/man1
install -m 644 mame.6 %{buildroot}%{_mandir}/man6
popd

%clean
rm -rf "%{buildroot}"

%files
%defattr(-,root,root,-)
%doc whatsnew*.txt docs/
%doc %{_mandir}/man6/mame.6*
%dir %{_sysconfdir}/mame
%config(noreplace) %{_sysconfdir}/mame/mame.ini
%dir %{_datadir}/mame/
%{_datadir}/mame/
%{_bindir}/mame

%files tools
%defattr(-,root,root,-)
%doc %{_mandir}/man1/chdman.1*
%doc %{_mandir}/man1/jedutil.1*
%doc %{_mandir}/man1/ldverify.1*
%doc %{_mandir}/man1/mame-testkeys.1*
%doc %{_mandir}/man1/romcmp.1*
%{_bindir}/chdman
%{_bindir}/jedutil
%{_bindir}/ldresample
%{_bindir}/ldverify
%{_bindir}/mame-regrep
%{_bindir}/mame-srcclean
%{_bindir}/mame-src2html
%{_bindir}/mame-split
%{_bindir}/mame-testkeys
%{_bindir}/romcmp
%{_bindir}/unidasm

%changelog
* Sun Nov 27 2011 gber@opensuse.org
- update to version 0.144
  * many bugfixes and improvements
  * new games
    + Dirt Dash
    + Galaxy Game
    + Waku Waku Doubutsu Land TonTon
    + Kasino '89
    + Novo Play Multi Card / Club Card
    + PEPSI Man
    + Uchuu Tokkyuu Medalian
    + Funcube 3
    + FamicomBox
    + Bingo (set 1)
    + Bingo (set 2)
    + 30 Test (Remake)
    + Candy Candy
    + Deluxe 5
    + PEPSI Man
    + Super Shot
    + Umi de Poker / Marine Paradise
    + Slot Poker Saiyuki
    + Ridge Racer 2
    + Free Kick
    + Mahjong Tian Jiang Shen Bing (V137C)
    + Densha de GO!
    + Densha de GO! 2
    + Landing Gear
    + Penky
    + Enchanted Forest (12XF528902, US)
    + Arctic Wins (4XF5227H03, US)
    + GP Rider (set 2, World, FD1094 317-0163)
    + Hanafuda Hana Gokou Bangaihen
  * new clones
    + King of the Monsters 2 - The Next Thing (prototype)
    + Alien Front (Rev T)
    + House of the Dead 2 (prototype)
    + 18 Wheeler (Rev. A)
    + Zero Team (set 5, Korea, Dream Soft license)
    + Battle Shark (Japan, Joystick)
    + Crash (bootleg of Head On)
    + Gunbuster (US)
    + Mustafa and 40 Thieves (Bootleg)
    + Flyball (rev 2)
    + Bad Lands (bootleg, alternate)
    + Witch Card (Video Klein CPU box, set 2)
    + Alpha Mission 2 (prototype)
    + Burning Fight (prototype)
    + Jungle King (alternate sound)
    + Zero Gunner (Japan, Model 2A)
    + Last Bronx (USA, Revision A)
    + Viper Phase 1 (USA, New Version, set 2)
    + Vigilante (US) - Rev. G
    + Cruis'n Exotica v1.0
    + NBA Jam T.E. Nani Edition (rev 5.2 8/11/95)
    + Muroge Monaco (set 3)
    + Butasan - Pig's & Bomber's (Japan, English)
    + Aqua Jack (US)
    + Ikari 3 (Japan)
    + Exvania (World)
    + 1943: Midway Kaisen (Japan, Rev B)
    + Rad Rally (Japan)
    + The King of Fighters '97 (Korean release)
    + Phoenix (Irecsa / G.G.I Corp - set 2)
    + Rescue (bootleg) (not working)
    + The End (bootleg) (not working)
    + Missile Combat (Sidam bootleg) (not working)
    + Biomechanical Toy (Ver. 1.0.1884)
    + Shocking (Korea)
    + Puzz Loop (Europe, v0.94)
    + Donkey King Jr. (bootleg of Donkey Kong Jr.)
    + Sauro (Philko license)
    + Raiders (Rev.3)
    + Magic Card Export 94
    + Sagaia (dual screen) (World)
    + Mortal Kombat (Nifty Kombo, hack)
    + Mortal Kombat (Nifty Kombo 666, hack)
    + Savanna (Jungler bootleg)
    + Pit Boss Megatouch II (9255-10-01 ROD, Standard version)
    + Galivan - Cosmo Police (12/26/1985)
    + Missile Command (rev 3)
* Fri Aug  5 2011 gber@opensuse.org
- update to version 0.143
  * many bugfixes and improvements
  * new games
    + Warp Speed (prototype)
    + Mortal Kombat 4 (version 1.0)
    + Baryon Future Assault
    + Reality Tennis
    + Fruit Bonus '06 - 10th anniversary
    + Super Ball (Version 1.3)
    + Doraemon no Eawase Montage (prototype)
    + Chequered Flag
    + Super Wing
    + Mighty Guy
    + Major Poker (v2.0)
    + Witch Royal (Export version 2.1)
    + Water-Nymph (Ver. 1.4)
  * new clones
    + Terra Force (Japan)
    + Street Fighter II: The World Warrior (USA 910306)
    + Final Fight (USA, set 2)
    + Leader Board (Arcadia, set 3)
    + OnePlay Version 2.20 bios
    + Heated Barrel (Electronic Devices license)
    + Tekken 3 (Japan, TET1/VER.A)
    + Tekken 3 (Asia, TET2/VER.E1)
    + The Real Ghostbusters (US 2 Players, revision 2)
    + Dream Crown (Set 2)
    + Harley Davidson (Rev.B)
    + Motocross Go (MG2 Ver.A)
    + Nouryoku Koujou Iinkai (prototype)
    + Pit Boss Superstar (9221-10-00A)
    + Champion Poker (v100)
    + Gunbarl (Japan, GNB4/VER.A)
    + Amidar (Konami/1982)
    + Witch Card (German, WC3050, 27-4-94)
    + Tekken 2 (TES3 VER.D)
    + Soul Edge (SO2/VER.A)
    + Soul Calibur (SOC13 VER.C)
    + Tekken Tag (TEG2 VER.C1)
    + Street Fighter III: New Generation (Hispanic 970204)
* Mon Apr 11 2011 gber@opensuse.org
- update to version 0.142
  * many bugfixes and improvements
  * implemented "-watchdog" option for SDLMame
  * copied the "-bench" option from win32 to sdl
  * added "-syncrefresh" option which in combination with
    "-waitsync" limits the game speed to the video refresh rate
  * new games
    + Mr. Kicker
    + X-Plan
    + Penfan Girls
    + Witch Card (Video Klein CPU box)
    + Jolli Witch (Export, 6T/12T ver 1.57D)
    + Wild Witch (Export, 6T/12T ver 1.74A)
    + Express Card / Top Card
    + Magic Train
    + X-Train
    + Music Sort (ver 2.02, English)
    + 18 Wheeler
    + Animal Catch
    + Itazura Monkey
    + California Games (Mega-Tech)
    + Hae Hae Ka Ka Ka
    + Pye-nage Taikai
    + Taihou de Doboon
    + Dance Dance Revolution 2nd Mix - Link Ver (GE885 VER. JAB)
    + Guilty Gear X 1.5
    + Brasil 86
    + Brasil 87
    + Brasil 89 (set 2)
    + Brasil 93
    + Reel'N Quake
    + Ruleta RE-800 (earlier)
    + Ruleta RE-800 (v1.0)
    + Ruleta RE-800 (v3.0)
    + Galactica
    + Lucky Roulette (6-players, Spanish)
    + Super Twenty One
    + Ruleta RCI (6-players, Spanish)
    + Winners Circle 82
    + Winners Circle (81, 28*28 PCB)
    + Winners Circle (81, 18*22 PCB)
  * new clones
    + Sega Touring Car Championship (Newer)
    + Sega Touring Car Championship (Unknown Revision)
    + Mahjong Man Guan Da Heng (Taiwan, V125T1)
    + Zero Team Suicide Revival Kit
    + Bombjack Twin (prototype? with adult pictures)
    + Sexy Parodius (ver AAA)
    + Ring of Destruction: Slammasters II (Asia 940831)
    + Street Fighter Alpha 2 (USA 960430)
    + Gekirindan (Ver 2.30 1995/09/21)
    + 1943: Battle of Midway (bootleg, hack of Japan set)
    + Scramble (bootleg?)
    + Zero Target (World, CW)
    + Space Bomber
    + Top Skater (Japan)
    + Prehistoric Isle in 1930 (Korea)
    + Zero Hour (set 2)
    + Hidden Catch 2 (pcb ver 1.00) (Kor/Eng/Jpn/Chi)
    + Tenchi wo Kurau (Japan Resale Ver.)
    + Red Earth / Warzard (961023)
    + Double Dribble (prototype?)
    + Tetris Plus 2 (Japan, V2.1)
    + Violent Storm (ver AAB)
    + Black Tiger (older)
    + Whirlwind (LG-3)
    + Real Mahjong Gold Yumehai / Super Real Mahjong GOLD part.2
    (BET version of Super Real Mahjong Part 3)
    + Video Hustler (Dynamo Games)
    + Hot Memory (V1.1, Germany)
    + Pigskin 621AD (rev 2.0 7/06/90)
    + Wild West C.O.W.-Boys of Moo Mesa (ver UA, set 1)
    + Bubble Pong Pong (clone of Miss Bubble 2)
    + Knights of Valour 2 / Sangoku Senki 2 (ver. 101, 101, 100HK)
    + Monopoly (3.01)
    + Monopoly (2.51)
    + Monopoly (2.33)
    + Austin Powers (3.01)
    + Austin Powers (3.00)
    + Austin Powers (2.01)
    + Maverick (Display Rev. 4.00)
    + Cut The Cheese (Redemption)[destruk]
    + Cut The Cheese Deluxe (Redemption)[destruk]
    + Night Rider (rev. 21)
    + Eight Ball Deluxe (rev. 14)
    + Lord Of The Rings, The (9,8,7,401)(En,Sp,Ger,Fr,It)
    + Elvis (4.00,3.03,3.02) (En,Sp,It,Fr,Ger)
    + Ripley's Believe It or Not! (3.10,3.02,3.00) (En,Sp,It,Fr,Ger)
    + Sharkey's Shootout (2.07) (En,Ger,Fr,It)
    + Terminator 3: Rise of the Machines (2.05) (En,Sp,Fr,It)
    + Playboy (3.03,3.00) (En,Sp,Fr,It,Ger)
    + Roller Coaster Tycoon (7.01,4.00) (En,Sp,Fr,It,Ger)
    + Big Twin (No Girls Conversion)
    + Super Star Crest
    + 1941: Counter Attack (USA 900227)
    + Simpsons Pinball Party (4.00,2.04) (En,Sp,Fr,It,Ger)
    + Grand Prix (4.00,3.40,3.01) (En,Sp,Fr,It,Ger)
    + Nascar (4.00,3.50,3.40, 3.01) (En,Sp)
    + Sopranos (3.00, 2.04, 1.07) (En,Sp,Fr,It,Ger)
    + High Roller Casino (2.10)
    + Playboy (4.01,2.03) (En,Sp,Fr,It,Ger)
    + Roller Coaster Tycoon (6.00) (En,Sp,Fr,It)
    + Street Fighter Alpha 3 (Hispanic 980904)
    + Empire City: 1931 (Italy)
    + Thunder & Lightning (bootleg with Tetris sound)
    + The Pit (US, set 2)
    + Terra Cresta (newer PCB)
    + Speak & Rescue (bootleg)
    + Heavy Unit -U.S.A. Version-
    + Ropeman (bootleg of Roc'n Rope)
    + Fashion Gambler (Set 2)
    + AAcrobatic Dog-Fight (USA)
- specfile cleanup
* Fri Jan 14 2011 guido+packman@berhoerster.name
- update to 0.141
  * added new option -uifont to specify the UI font
  * many bugfixes and improvements
  * new games
    + Heavy Unit
    + Poizone
    + Silver Game
    + Jack Potten's Poker (NGold) (3 sets)
    + Bullet
    + Rumba Lumber
    + Deluxe Trivia ? Whiz (Edition 5)
    + Denjin Makai
    + Balloon & Balloon (BnB Arcade)
    + Happy Tour
    + Dai San Wakusei Meteor
    + Pac-Slot
    + Super Double (French)
    + Pit Boss Megatouch II
    + Royal Card (TAB original)
    + Janputer Special
    + Bygone
  * new clones
    + Multi Champ Deluxe (ver. 1114, 14/11/1999) (not working)
    + Gran Tesoro? / Play 2000 (v4.0) (Italy) (not working)
    + Raiden (US, set 2)
    + Golden Tee Golf (Trackball, v2.0)
    + Relief Pitcher (set 2, 26 Apr 1992 / 08 Apr 1992)
    + G.I. Joe (World, EB8, prototype?)
    + Space Firebird (2 sets)
    + World Class Bowling v1.4
    + Ataxx (Europe)
    + Gals Ds - Three Dealers Casino House (bootleg?)
    + Gyruss (bootleg)
    + Parodius DA! (World, set 2)
    + Gals Panic 2 (Italy)
    + Quester Special Edition (Japan)
    + Tic Tac Trivia (Vertical)
    + Raiden II (set 7, US Fabtek) (not working)
    + The King of Dragons (World 910805)
    + Mega Man: The Power Battle (CPS1, USA 951006)
    + Street Fighter II: The World Warrior (World 910228)
    + Super Space Invaders '91
    + Megatouch III (9255-20-06 ROD, California version)
    + Megatouch IV (9255-40-01 ROB, Standard version)
    + Super Megatouch IV (9255-41-01 ROG, Standard version)
    + Mortal Kombat (prototype, rev 4.0 07/14/92)
    + Mortal Kombat II (rev L1.1)
    + Buccaneer
    + Jungle Boy
    + Bee Storm - DoDonpachi II (ver 101) (not working)
    + Sunset Riders 2 (bootleg)
    + Buck Rogers: Planet of Zoom (not encrypted, set 2)
    + Time Killers (v1.21)
    + Dogyuun (test location version)
    + Pit Boss Megatouch II 9255-10-01 R0E
    + JoJo's Venture (USA 990108)
    + JoJo's Venture (USA 981202)
    + Moon Shuttle (US? set 2)
    + Mega Double Poker (conversion kit, set 2)
    + Mahjong Neruton Haikujiradan (Japan, Rev. A?)
* Fri Dec 24 2010 guido+packman@berhoerster.name
- update to 0.140
  * many bugfixes and improvements
  * new games
    + Devil Island (2 sets)
    + Tetris / Bloxeed (Korean System 16 bootleg) (ISG Selection
    Master Type 2006)
    + Mallet Madness v2.1
    + Piccolo Poker 100
    + Witch Card (Falcon, enhanced sound)
    + Witch Card (German, set 3, alt gfx)
    + Witch Game (Video Klein)
    + Falcons Wild - Wild Card 1991 (TVG)
    + Falcons Wild - World Wide Poker (Video Klein)
    + Victor 6
    + Quizard 1.7
    + Quizard 1.2
    + Quizard 2.2
    + Shinobi / FZ-2006 (Korean System 16 bootleg) (ISG Selection
    Master Type 2006)
    + Poker Master (Tony-Poker V3.A, hack?)
    + Raiden Fighters (Asia?, Metrotainment license)
    + Genie
    + Doki Doki Idol Star Seeker
    + 3 Bags Full - 5VXFC790 (Victorian)
    + Cal Omega - Game 8.0 (Arcade Black Jack)
    + Cal Omega - Game 24.0 (Gaming Draw Poker, hold)
    + Fire Trap (Japan)
    + Royal Card (Nichibutsu)
    + Pacman - 25th Anniversary Edition (V2.0)
    + The Last Starfighter (prototype)
    + Air Race (prototype)
  * new clones
    + Streaking (set 2)
    + Sea Wolf (older?)
    + Gun Fight (older?)
    + Puckman Pockimon (set 2)
    + Hit Me
    + X-Men: Children of the Atom (Asia 950105)
    + Final Lap 3 (Japan - Rev C)
    + Omega Race (set 2)
    + Star Raker
    + Vigilante (World, set 2)
    + Sega Rally Championship (Revision B)
    + Touchmaster 2000 Plus (v4.63 Standard)
    + Touchmaster 4000 (v6.01 Standard)
    + Pioneer Balloon (Rock-Ola license)
    + Legion (bootleg of Legend)
    + Eco Fighters (Phoenix Edition)
    + Knights of the Round (Japan 911127, B-Board 89625B-1)
    + The King of Dragons (Japan 910805, B-Board 89625B-1)
    + Street Fighter II': Champion Edition (World 920513)
    + Willow (Japan, Japanese)
    + Yie Ar Kung-Fu (GX361 conversion)
    + Super Poker (Version 10.15S)
    + Clash-Road (Data East license)
    + Quizard v1.2
    + Quizard Rainbow 4.2
    + Super Megatouch IV Turnier Version (9255-51-50 ROA,
    Bi-Lingual ENG/GER version)
    + Megatouch 5 Turnier Version (9255-70-50 RON, Bi-Lingual
    ENG/GER version)
    + Knights of the Round (Japan 911127, 91634B-2 B-Board)
    + Area 88 (Japan Resale Ver.)
    + Ms. Pac-Man/Galaga - 20th Anniversary Class of 1981 Reunion
    (V1.00)
    + Ms. Pac-Man/Galaga - 20th Anniversary Class of 1981 Reunion
    (V1.03)
* Sat Jul 31 2010 guido+packman@berhoerster.name
- specfile cleaned up
- update to version 0.139
- dropped Debian manpages, now included
* Fri Mar 12 2010 guido+packman@berhoerster.name
- initial packaging of mame
